@@ -49,7 +49,7 @@ class Tuple2(click.ParamType):
 
 @click.group()
 @click.option("-p", "--parallel", default=1, help="Run with this number of parallel processes. If 0, use number of cores.")
-@click.version_option(version="0.7.0")
+@click.version_option(version="0.8.0")
 @click.pass_context
 def main(ctx, parallel):
   """
@@ -201,6 +201,7 @@ def downsample(
 @click.option('--bg-color', default=0, help="Determines which color is regarded as background.", show_default=True)
 @click.option('--sharded', is_flag=True, default=False, help="Generate a sharded dataset which reduces the number of files. Downsamples are not generated.")
 @click.option('--dest-voxel-offset', type=Tuple3(), default=None, help="Set the voxel offset for this mip level.")
+@click.option('--clean-info', is_flag=True, default=False, help="Scrub info file of mesh and skeleton fields.", show_default=True)
 @click.pass_context
 def xfer(
 	ctx, src, dest, queue, translate, 
@@ -208,7 +209,7 @@ def xfer(
   memory, max_mips, shape, sparse, 
   cseg, compresso, chunk_size, compress, 
   volumetric, delete_bg, bg_color, sharded,
-  dest_voxel_offset
+  dest_voxel_offset, clean_info
 ):
   """
   Transfer an image layer to another location.
@@ -250,7 +251,7 @@ def xfer(
       src, dest,
       chunk_size=chunk_size, fill_missing=fill_missing, mip=mip, 
       dest_voxel_offset=dest_voxel_offset, translate=translate, 
-      encoding=encoding, memory_target=memory,
+      encoding=encoding, memory_target=memory, clean_info=clean_info
     )
   else:
     tasks = tc.create_transfer_tasks(
@@ -260,7 +261,7 @@ def xfer(
       mip=mip, shape=shape, encoding=encoding, skip_downsamples=(not downsample),
       delete_black_uploads=delete_bg, background_color=bg_color,
       compress=compress, factor=factor, sparse=sparse,
-      memory_target=memory, max_mips=max_mips
+      memory_target=memory, max_mips=max_mips, clean_info=clean_info
     )
 
   parallel = int(ctx.obj.get("parallel", 1))
